@@ -1,6 +1,7 @@
 ## ----include = FALSE----------------------------------------------------------
 knitr::opts_chunk$set(
   collapse = TRUE,
+  eval = rlang::is_installed("duckdb"),
   # eval = FALSE,
   comment = "#>"
 )
@@ -24,63 +25,51 @@ library(dplyr)
 write_schema <- "main"
 cdm_schema <- "main"
 
-con <- DBI::dbConnect(duckdb::duckdb(), dbdir = eunomia_dir())
-cdm <- cdm_from_con(con, cdm_name = "eunomia", cdm_schema = cdm_schema, write_schema = write_schema)
-
-## -----------------------------------------------------------------------------
-#attr(cdm, "cdm_name")
+con <- DBI::dbConnect(duckdb::duckdb(), 
+                      dbdir = eunomia_dir())
+cdm <- cdm_from_con(con, 
+                    cdm_name = "eunomia", 
+                    cdm_schema = cdm_schema, 
+                    write_schema = write_schema, 
+                    cdm_version = "5.3")
 
 ## -----------------------------------------------------------------------------
 cdmName(cdm)
 cdm_name(cdm)
 
 ## -----------------------------------------------------------------------------
-#attr(cdm, "cdm_version")
+cdmVersion(cdm)
 
 ## -----------------------------------------------------------------------------
-#cdmCon(cdm)
+cdmCon(cdm)
 
 ## -----------------------------------------------------------------------------
-#DBI::dbListTables(cdmCon(cdm))
-#DBI::dbListFields(cdmCon(cdm), "person")
-#DBI::dbGetQuery(cdmCon(cdm), "SELECT * FROM person LIMIT 5")
+DBI::dbListTables(cdmCon(cdm))
+DBI::dbListFields(cdmCon(cdm), "person")
+DBI::dbGetQuery(cdmCon(cdm), "SELECT * FROM person LIMIT 5")
 
-## -----------------------------------------------------------------------------
-
-# debugonce(generateConceptCohortSet)
-cdm <- generateConceptCohortSet(cdm = cdm, 
-                                conceptSet = list("gi_bleed" = 192671,
-                                                  "celecoxib" = 1118084), 
-                                name = "study_cohorts",
-                                overwrite = TRUE)
-
-cdm$study_cohorts %>% 
-  glimpse()
-
-## -----------------------------------------------------------------------------
-attr(cdm$study_cohorts, "cohort_set")
+## ----eval=FALSE---------------------------------------------------------------
+#  cdm <- generateConceptCohortSet(cdm = cdm,
+#                                  conceptSet = list("gi_bleed" = 192671,
+#                                                    "celecoxib" = 1118084),
+#                                  name = "study_cohorts",
+#                                  overwrite = TRUE)
+#  
+#  cdm$study_cohorts %>%
+#    glimpse()
 
 ## ----eval=FALSE---------------------------------------------------------------
 #  settings(cdm$study_cohorts)
 #  cohort_set(cdm$study_cohorts)
 
-## -----------------------------------------------------------------------------
-attr(cdm$study_cohorts, "cohort_count")
-
 ## ----eval=FALSE---------------------------------------------------------------
 #  cohortCount(cdm$study_cohorts)
 #  cohort_count(cdm$study_cohorts)
 
-## ----eval=FALSE---------------------------------------------------------------
-#  attr(cdm$study_cohorts, "cohort_attrition")
-
 ## ----eval=FALSE---------------------------------------------------------------
 #  cohortAttrition(cdm$study_cohorts)
 #  cohort_attrition(cdm$study_cohorts)
 
-## -----------------------------------------------------------------------------
-attr(cdm$study_cohorts, "cdm_reference")
-
 ## -----------------------------------------------------------------------------
 cdm$gi_bleed <- cdm$condition_occurrence %>% 
   filter(condition_concept_id == 192671) %>% 
@@ -107,5 +96,4 @@ cdm$gi_bleed <- omopgenerics::newCohortTable(
 settings(cdm$gi_bleed)
 cohortCount(cdm$gi_bleed)
 cohortAttrition(cdm$gi_bleed)
-attr(cdm$gi_bleed, "cdm_reference")
 
