@@ -75,111 +75,112 @@ test_that("Uppercase tables are stored as lowercase in cdm", {
   DBI::dbDisconnect(con, shutdown = TRUE)
 })
 
+# TODO add this test back when we have an example cdm with achilles tables
+# test_that("adding achilles", {
+#   skip_if_not(eunomia_is_available())
+#   skip_if_not_installed("duckdb")
+#
+#   con <- DBI::dbConnect(duckdb::duckdb(eunomia_dir()))
+#
+#   expect_error(cdm_from_con(con = con,
+#                             cdm_schema =  "main",
+#                             write_schema = "main",
+#                             achilles_schema = "main"))
+#
+#   DBI::dbWriteTable(
+#     conn = con,
+#     name = "achilles_analysis",
+#     value = tibble(
+#       analysis_id = 1L, analysis_name = "1", stratum_1_name = "1",
+#       stratum_2_name = "1", stratum_3_name = "1", stratum_4_name = "1",
+#       stratum_5_name = "1", is_default = 1L, category = "1"),
+#     overwrite = TRUE
+#   )
+#
+#   DBI::dbWriteTable(
+#     conn = con,
+#     name = "achilles_results",
+#     value = tibble(analysis_id = 1L,
+#                    stratum_1 = "a",
+#                    stratum_2 = "b",
+#                    stratum_3 = "1",
+#                    stratum_4 = "5",
+#                    stratum_5 = "u",
+#                    count_value = 1500L),
+#     overwrite = TRUE
+#   )
+#
+#   DBI::dbWriteTable(
+#     conn = con,
+#     name = "achilles_results_dist",
+#     value = tibble(
+#       analysis_id = 1L, count_value = 5L, stratum_1 = "1", stratum_2 = "1",
+#       stratum_3 = "1", stratum_4 = "1", stratum_5 = "1", min_value = 1, max_value = 1,
+#       avg_value = 1, stdev_value = 1, median_value = 1, p10_value = 1,
+#       p25_value = 1, p75_value = 1, p90_value = 1),
+#     overwrite = TRUE
+#   )
+#
+#   cdm <- cdm_from_con(con = con,
+#                       cdm_schema =  "main",
+#                       write_schema = "main",
+#                       achilles_schema = "main")
+#
+#  expect_true(cdm$achilles_analysis %>% dplyr::pull("analysis_name") == 1)
+#  expect_true(cdm$achilles_results %>% dplyr::pull("stratum_1") == "a")
+#  expect_true(cdm$achilles_results_dist %>% dplyr::pull("count_value") == 5)
+#
+#  # we should also be able to add achilles tables manually if in db
+#  cdm <- cdm_from_con(
+#    con = con, cdm_name = "eunomia", cdm_schema =  "main", write_schema = "main"
+#  )
+#  cdm$achilles_analysis <- dplyr::tbl(con, "achilles_analysis")
+#  # but should not work if tables are not in db (as cdm is db side)
+#  expect_error(
+#    cdm$achilles_analysis <- dplyr::tibble(
+#      analysis_id = 1, analysis_name = 1, stratum_1_name = 1,
+#      stratum_2_name = 1, stratum_3_name = 1, stratum_4_name = 1,
+#      stratum_5_name = 1, is_default = 1, category = 1
+#    )
+#   )
+# # if local tables, insert table would take care of this
+#
+#  achilles_analysis_tibble <- dplyr::tibble(
+#    analysis_id = 1, analysis_name = 1, stratum_1_name = 1,
+#    stratum_2_name = 1, stratum_3_name = 1, stratum_4_name = 1,
+#    stratum_5_name = 1, is_default = 1, category = 1
+#  )
+#  cdm <- omopgenerics::insertTable(cdm = cdm,
+#                                   table = achilles_analysis_tibble,
+#                                   name = "achilles_analysis",
+#                                   overwrite = TRUE)
+#
+#  cdm$achilles_analysis <- dplyr::tbl(con, "achilles_analysis")
+#
+#  # but should not work if tables are not in db (as cdm is db side)
+#   expect_error(
+#     cdm$achilles_analysis <- dplyr::tibble(
+#       analysis_id = 1, analysis_name = 1, stratum_1_name = 1,
+#       stratum_2_name = 1, stratum_3_name = 1, stratum_4_name = 1,
+#       stratum_5_name = 1, is_default = 1, category = 1
+#   ))
+#
+#  # if local tables, insert table would take care of this
+#   achilles_analysis_tibble <- dplyr::tibble(
+#     analysis_id = 1, analysis_name = 1, stratum_1_name = 1,
+#     stratum_2_name = 1, stratum_3_name = 1, stratum_4_name = 1,
+#     stratum_5_name = 1, is_default = 1, category = 1
+#   )
+#
+#   cdm <- omopgenerics::insertTable(cdm = cdm,
+#                                     table = achilles_analysis_tibble,
+#                                     name = "achilles_analysis",
+#                                     overwrite = TRUE)
+#
+#   DBI::dbDisconnect(con, shutdown = TRUE)
+# })
 
-test_that("adding achilles", {
-  skip_if_not(eunomia_is_available())
-  skip_if_not_installed("duckdb")
-
-  con <- DBI::dbConnect(duckdb::duckdb(eunomia_dir()))
-
-  expect_error(cdm_from_con(con = con,
-                            cdm_schema =  "main",
-                            write_schema = "main",
-                            achilles_schema = "main"))
-
-  DBI::dbWriteTable(
-    conn = con,
-    name = "achilles_analysis",
-    value = tibble(
-      analysis_id = 1, analysis_name = 1, stratum_1_name = 1,
-      stratum_2_name = 1, stratum_3_name = 1, stratum_4_name = 1,
-      stratum_5_name = 1, is_default = 1, category = 1),
-    overwrite = TRUE)
-
-  DBI::dbWriteTable(
-    conn = con,
-    name = "achilles_results",
-    value = tibble(analysis_id = 1,
-                   stratum_1 = "a",
-                   stratum_2 = "b",
-                   stratum_3 = 1,
-                   stratum_4 = 5,
-                   stratum_5 = "u",
-                   count_value = 1500),
-    overwrite = TRUE
-  )
-
-  DBI::dbWriteTable(
-    conn = con,
-    name = "achilles_results_dist",
-    value = tibble(
-      analysis_id = 1, count_value = 5, stratum_1 = 1, stratum_2 = 1,
-      stratum_3 = 1, stratum_4 = 1, stratum_5 = 1, min_value = 1, max_value = 1,
-      avg_value = 1, stdev_value = 1, median_value = 1, p10_value = 1,
-      p25_value = 1, p75_value = 1, p90_value = 1),
-    overwrite = TRUE
-  )
-
-  cdm <- cdm_from_con(con = con,
-                      cdm_schema =  "main",
-                      write_schema = "main",
-                      achilles_schema = "main")
-
- expect_true(cdm$achilles_analysis %>% dplyr::pull("analysis_name") == 1)
- expect_true(cdm$achilles_results %>% dplyr::pull("stratum_1") == "a")
- expect_true(cdm$achilles_results_dist %>% dplyr::pull("count_value") == 5)
-
- # we should also be able to add achilles tables manually if in db
- cdm <- cdm_from_con(
-   con = con, cdm_name = "eunomia", cdm_schema =  "main", write_schema = "main"
- )
- cdm$achilles_analysis <- dplyr::tbl(con, "achilles_analysis")
- # but should not work if tables are not in db (as cdm is db side)
- expect_error(
-   cdm$achilles_analysis <- dplyr::tibble(
-     analysis_id = 1, analysis_name = 1, stratum_1_name = 1,
-     stratum_2_name = 1, stratum_3_name = 1, stratum_4_name = 1,
-     stratum_5_name = 1, is_default = 1, category = 1
-   )
-  )
-# if local tables, insert table would take care of this
-
- achilles_analysis_tibble <- dplyr::tibble(
-   analysis_id = 1, analysis_name = 1, stratum_1_name = 1,
-   stratum_2_name = 1, stratum_3_name = 1, stratum_4_name = 1,
-   stratum_5_name = 1, is_default = 1, category = 1
- )
- cdm <- omopgenerics::insertTable(cdm = cdm,
-                                  table = achilles_analysis_tibble,
-                                  name = "achilles_analysis",
-                                  overwrite = TRUE)
-
- cdm$achilles_analysis <- dplyr::tbl(con, "achilles_analysis")
-
- # but should not work if tables are not in db (as cdm is db side)
-  expect_error(
-    cdm$achilles_analysis <- dplyr::tibble(
-      analysis_id = 1, analysis_name = 1, stratum_1_name = 1,
-      stratum_2_name = 1, stratum_3_name = 1, stratum_4_name = 1,
-      stratum_5_name = 1, is_default = 1, category = 1
-  ))
-
- # if local tables, insert table would take care of this
-  achilles_analysis_tibble <- dplyr::tibble(
-    analysis_id = 1, analysis_name = 1, stratum_1_name = 1,
-    stratum_2_name = 1, stratum_3_name = 1, stratum_4_name = 1,
-    stratum_5_name = 1, is_default = 1, category = 1
-  )
-
-  cdm <- omopgenerics::insertTable(cdm = cdm,
-                                    table = achilles_analysis_tibble,
-                                    name = "achilles_analysis",
-                                    overwrite = TRUE)
-
-  DBI::dbDisconnect(con, shutdown = TRUE)
-})
-
-test_that("adding achilles", {
+test_that("adding cohort tables to the cdm", {
   skip_if_not(eunomia_is_available())
   skip_if_not_installed("duckdb")
 
@@ -193,8 +194,8 @@ test_that("adding achilles", {
 
   cohort_table <- dplyr::tribble(
     ~cohort_definition_id, ~subject_id, ~cohort_start_date,    ~cohort_end_date,
-    1,                     5,           as.Date("2020-01-01"), as.Date("2020-01-01"),
-    2,                     5,           as.Date("2020-01-10"), as.Date("2020-03-10")
+    1L,                     5L,           as.Date("2020-01-01"), as.Date("2020-01-01"),
+    2L,                     5L,           as.Date("2020-01-10"), as.Date("2020-03-10")
   )
 
   dplyr::copy_to(dest = con,
@@ -202,6 +203,9 @@ test_that("adding achilles", {
                  name = "test_cohort_table",
                  overwrite = TRUE)
 
+  expect_equal(unname(sapply(DBI::dbReadTable(con, "test_cohort_table"), class)),
+               c("integer", "integer", "Date", "Date"))
+
   expect_error(cdmFromCon(con,
                     cdmSchema = "main",
                     writeSchema = c(schema = "main"),
@@ -218,6 +222,7 @@ test_that("adding achilles", {
 })
 
 test_that("write_schema argument specification and cdm_disconnect works", {
+  skip_if_not_installed("duckdb")
   con <- DBI::dbConnect(duckdb::duckdb(), eunomia_dir())
   cdm <- cdm_from_con(con, "main", "main", write_prefix = "tmp_")
 
